===========================
hiperwalk.CompleteBipartite
===========================

.. currentmodule:: hiperwalk

.. autofunction:: CompleteBipartite

Methods
-------

All methods are inherited from
:class:`hiperwalk.Graph`,
:class:`hiperwalk.Multigraph`,
or :class:`hiperwalk.WeightedGraph`.
